vbvarsel.data_sim_crook — vbvarsel 0.0.1 documentation

# vbvarsel.data_sim_crook

## Classes

`SimulateCrookData` | A class to represent simulated data as described by Crook et al. Data will

## Module Contents

class vbvarsel.data_sim_crook.SimulateCrookData(observation: int, n_variables: int, n_relevant: int, mixture_proportions: list, means: list, variance_covariance_matrix: numpy.ndarray)

  A class to represent simulated data as described by Crook et al. Data will be generated in accordance to the parameters passed through `vbvarsel.global_parameters.SimulationParameters()`. This only generates synthetic data, and as such is not used if a user supplies their own data source. Reference paper

  observation
  n_variables
  n_relevant
  mixture_proportions
  means
  variance_covariance_matrix
  ExperimentValues
  relevant_vars() → numpy.ndarray

    Returns array of relevant variables for use in simulation.

  irrelevant_vars() → numpy.ndarray

    Returns array of irrelevant variables in simulation.

  data_sim() → numpy.ndarray

    Returns simulated data array.

  permutation() → numpy.ndarray

    Returns permutations for simulation.

  shuffle_sim_data(data, permutation) → numpy.ndarray

    Shuffles randomised data for simulation.

    Params
      data: np.ndarray

        Array of data generated from self.data_sim()

      permutation: np.ndarray

        Array of permutations generated from self.permutations()